@@ -5,11 +5,13 @@ from bblib.utils import (
     center_of_mass,
     azimuthal_average,
     gaussian_lin,
-    open_fwhm_map_global_min,
-    open_distance_map_global_min,
+    get_fwhm_map_global_min,
+    get_distance_map_global_min,
     correct_polarization,
+    visualize_single_panel
 )
 import math
+from scipy import ndimage
 from bblib.models import PF8Info, PF8
 import h5py
 import numpy as np
@@ -17,7 +19,8 @@ import matplotlib.pyplot as plt
 from skimage.transform import hough_circle, hough_circle_peaks
 from skimage.feature import canny
 import multiprocessing
-
+import pathlib
+from scipy.optimize import curve_fit
 
 class CenteringMethod(ABC):
     @abstractmethod
@@ -41,31 +44,44 @@ class CenteringMethod(ABC):
 
 
 class CenterOfMass(CenteringMethod):
-    def __init__(self, config: dict, PF8Config: PF8Info):
+    def __init__(self, config: dict, PF8Config: PF8Info,  plots_info: dict = None):
         self.config = config
         self.PF8Config = PF8Config
+        self.plots_info = plots_info
+        if config["plots_flag"] and not plots_info:
+            raise ValueError("From config you want to save plots, please indicate the information to save the plots.")
+
 
     def _prep_for_centering(self, data: np.ndarray) -> None:
         self.initial_detector_center = self.PF8Config.get_detector_center()
         pf8 = PF8(self.PF8Config)
         peak_list = pf8.get_peaks_pf8(data=data)
         peak_list_x_in_frame, peak_list_y_in_frame = pf8.peak_list_in_slab(peak_list)
-        indices = np.ndarray((2, peak_list["num_peaks"]), dtype=int)
+        row_indexes = np.zeros(peak_list["num_peaks"], dtype=int)
+        col_indexes = np.zeros(peak_list["num_peaks"], dtype=int)
 
         for idx, k in enumerate(peak_list_y_in_frame):
             row_peak = int(k + self.initial_detector_center[1])
             col_peak = int(peak_list_x_in_frame[idx] + self.initial_detector_center[0])
-            indices[0, idx] = row_peak
-            indices[1, idx] = col_peak
-
+            row_indexes[idx] = row_peak
+            col_indexes[idx] = col_peak
+        peaks_indexes =(row_indexes, col_indexes)
+        
         # Assemble data and mask
         data_visualize = geometry.DataVisualizer(pixel_maps=self.PF8Config.pixel_maps)
 
         with h5py.File(f"{self.PF8Config.bad_pixel_map_filename}", "r") as f:
             mask = np.array(f[f"{self.PF8Config.bad_pixel_map_hdf5_path}"])
 
-        self.visual_data = data_visualize.visualize_data(data=data * mask)
-        visual_mask = data_visualize.visualize_data(data=mask).astype(int)
+        if (self.PF8Config.pf8_detector_info["nasics_x"] * self.PF8Config.pf8_detector_info["nasics_y"]
+                > 1
+            ):
+            self.visual_data = data_visualize.visualize_data(data=data * mask)
+            visual_mask = data_visualize.visualize_data(data=mask).astype(int)
+        else:
+            
+            self.visual_data = visualize_single_panel(data, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
+            visual_mask = visualize_single_panel(mask, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
 
         # JF for safety
         visual_mask[np.where(self.visual_data < 0)] = 0
@@ -73,9 +89,9 @@ class CenterOfMass(CenteringMethod):
         # Mask Bragg peaks
         peaks_mask = mask_peaks(
             visual_mask,
-            indices,
-            bragg=self.config["bragg_pos_center_of_mass"],
-            n=self.config["pixels_per_peak"],
+            peaks_indexes,
+            bragg=self.config["bragg_peaks_positions_for_center_of_mass_calculation"],
+            n=self.config["pixels_for_mask_of_bragg_peaks"],
         )
         self.mask_for_center_of_mass = peaks_mask * visual_mask
 
@@ -84,14 +100,30 @@ class CenterOfMass(CenteringMethod):
         if self.centering_converged(center):
             center[0] += self.config["offset"]["x"]
             center[1] += self.config["offset"]["y"]
-        return np.round(center, 1)
+
+        if self.config["plots_flag"]:
+            fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
+            ax1.imshow(self.visual_data*self.mask_for_center_of_mass, vmax=10, cmap="YlGn", origin="lower")
+            ax1.scatter(self.initial_detector_center[0], self.initial_detector_center[1], color='blue', marker='o', label=f"Initial detector center: ({np.round(self.initial_detector_center[0])}, {np.round(self.initial_detector_center[1])})")
+            ax1.scatter(center[0], center[1], color='r', marker='o', label=f"Refined detector center: ({center[0]}, {center[1]})")
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_of_mass/')
+            path.mkdir(parents=True, exist_ok=True)
+            ax1.legend()
+            plt.savefig(
+                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_of_mass/{self.plots_info["file_name"]}.png'
+            )
+            plt.close()
+        return np.round(center, 0)
 
 
 class CircleDetection(CenteringMethod):
-    def __init__(self, config: dict, PF8Config: PF8Info, plots_info: dict):
+    def __init__(self, config: dict, PF8Config: PF8Info, plots_info: dict =None):
         self.config = config
         self.PF8Config = PF8Config
         self.plots_info = plots_info
+        if config["plots_flag"] and not plots_info:
+            raise ValueError("From config you want to save plots, please indicate the information to save the plots.")
+
 
     def _prep_for_centering(self, data: np.ndarray) -> None:
         self.initial_detector_center = self.PF8Config.get_detector_center()
@@ -99,27 +131,36 @@ class CircleDetection(CenteringMethod):
         pf8 = PF8(self.PF8Config)
         peak_list = pf8.get_peaks_pf8(data=data)
         peak_list_x_in_frame, peak_list_y_in_frame = pf8.peak_list_in_slab(peak_list)
-        indices = np.ndarray((2, peak_list["num_peaks"]), dtype=int)
+        row_indexes = np.zeros(peak_list["num_peaks"], dtype=int)
+        col_indexes = np.zeros(peak_list["num_peaks"], dtype=int)
 
         for idx, k in enumerate(peak_list_y_in_frame):
             row_peak = int(k + self.initial_detector_center[1])
             col_peak = int(peak_list_x_in_frame[idx] + self.initial_detector_center[0])
-            indices[0, idx] = row_peak
-            indices[1, idx] = col_peak
-
+            row_indexes[idx] = row_peak
+            col_indexes[idx] = col_peak
+        peaks_indexes =(row_indexes, col_indexes)
+        
         # Assemble data and mask
         data_visualize = geometry.DataVisualizer(pixel_maps=self.PF8Config.pixel_maps)
 
         with h5py.File(f"{self.PF8Config.bad_pixel_map_filename}", "r") as f:
             mask = np.array(f[f"{self.PF8Config.bad_pixel_map_hdf5_path}"])
 
-        self.visual_data = data_visualize.visualize_data(data=data * mask)
-        visual_mask = data_visualize.visualize_data(data=mask).astype(int)
+        if (self.PF8Config.pf8_detector_info["nasics_x"] * self.PF8Config.pf8_detector_info["nasics_y"]
+                > 1
+            ):
+            self.visual_data = data_visualize.visualize_data(data=data * mask)
+            visual_mask = data_visualize.visualize_data(data=mask).astype(int)
+        else:
+            
+            self.visual_data = visualize_single_panel(data, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
+            visual_mask = visualize_single_panel(mask, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
 
         # JF for safety
         visual_mask[np.where(self.visual_data < 0)] = 0
         only_peaks_mask = mask_peaks(
-            visual_mask, indices, bragg=0, n=self.config["pixels_per_peak"]
+            visual_mask, peaks_indexes, bragg=0, n=self.config["pixels_for_mask_of_bragg_peaks"]
         )
         self.mask_for_circle_detection = only_peaks_mask * visual_mask
 
@@ -136,9 +177,11 @@ class CircleDetection(CenteringMethod):
 
         if self.config["plots_flag"]:
             fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
-            ax1.imshow(edges)
+            ax1.imshow(edges, origin="lower")
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/edges/')
+            path.mkdir(parents=True, exist_ok=True)
             plt.savefig(
-                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["run_label"]}/edges/{self.plots_info["file_label"]}_{self.plots_info["frame_index"]}.png'
+                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/edges/{self.plots_info["file_name"]}.png'
             )
             plt.close()
         # Detect radii
@@ -159,15 +202,30 @@ class CircleDetection(CenteringMethod):
             yc = -1
 
         center = [xc, yc]
+        if self.config["plots_flag"]:
+            fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
+            ax1.imshow(self.visual_data*self.mask_for_circle_detection, vmax=10, origin="lower", cmap="YlGn")
+            ax1.scatter(self.initial_detector_center[0], self.initial_detector_center[1], color='blue', marker='o', label=f"Initial detector center: ({np.round(self.initial_detector_center[0])}, {np.round(self.initial_detector_center[1])})")
+            ax1.scatter(center[0], center[1], color='r', marker='o', label=f"Refined detector center: ({center[0]}, {center[1]})")
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_circle_detection/')
+            path.mkdir(parents=True, exist_ok=True)
+            ax1.legend()
+            plt.savefig(
+                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_circle_detection/{self.plots_info["file_name"]}.png'
+            )
+            plt.close()
         return center
 
 
 class MinimizePeakFWHM(CenteringMethod):
-    def __init__(self, config: dict, PF8Config: PF8Info, plots_info: dict):
+    def __init__(self, config: dict, PF8Config: PF8Info, plots_info: dict = None):
         self.config = config
         self.PF8Config = PF8Config
         self.plots_info = plots_info
         self.plot_fwhm_flag = False
+        if config["plots_flag"] and not plots_info:
+            raise ValueError("From config you want to save plots, please indicate the information to save the plots.")
+
 
     def _calculate_fwhm(self, coordinate: tuple) -> dict:
         center_to_radial_average = coordinate
@@ -216,7 +274,7 @@ class MinimizePeakFWHM(CenteringMethod):
             ss_res = np.sum(residuals**2)
             ss_tot = np.sum((y - np.mean(y)) ** 2)
             r_squared = 1 - (ss_res / ss_tot)
-        except ZeroDivisionError:
+        except (ZeroDivisionError, RuntimeError):
             r_squared = 0
             fwhm = 10000
             popt = []
@@ -226,7 +284,7 @@ class MinimizePeakFWHM(CenteringMethod):
             x_fit = x.copy()
             y_fit = gaussian_lin(x_fit, *popt)
 
-            plt.vlines([x[0], x[-1]], 0, round(popt[0]) + 2, "r")
+            plt.vlines([x[0], x[-1]], 0, round(popt[0])*10, "r")
 
             plt.plot(
                 x_fit,
@@ -237,10 +295,12 @@ class MinimizePeakFWHM(CenteringMethod):
 
             plt.title("Azimuthal integration")
             plt.xlim(0, 500)
-            # plt.ylim(0, round(popt[0])+2)
+            plt.ylim(0, 5)
             plt.legend()
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/radial_average/')
+            path.mkdir(parents=True, exist_ok=True)
             plt.savefig(
-                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["run_label"]}/radial_average/{self.plots_info["file_label"]}_{self.plots_info["frame_index"]}.png'
+                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/radial_average/{self.plots_info["file_name"]}.png'
             )
             plt.close()
 
@@ -263,43 +323,56 @@ class MinimizePeakFWHM(CenteringMethod):
 
         peak_list = pf8.get_peaks_pf8(data=data)
         peak_list_x_in_frame, peak_list_y_in_frame = pf8.peak_list_in_slab(peak_list)
-        indices = np.ndarray((2, peak_list["num_peaks"]), dtype=int)
+        row_indexes = np.zeros(peak_list["num_peaks"], dtype=int)
+        col_indexes = np.zeros(peak_list["num_peaks"], dtype=int)
 
         for idx, k in enumerate(peak_list_y_in_frame):
             row_peak = int(k + self.initial_detector_center[1])
             col_peak = int(peak_list_x_in_frame[idx] + self.initial_detector_center[0])
-            indices[0, idx] = row_peak
-            indices[1, idx] = col_peak
-
+            row_indexes[idx] = row_peak
+            col_indexes[idx] = col_peak
+        peaks_indexes =(row_indexes, col_indexes)
+        
         # Assemble data and mask
         data_visualize = geometry.DataVisualizer(pixel_maps=self.PF8Config.pixel_maps)
 
         with h5py.File(f"{self.PF8Config.bad_pixel_map_filename}", "r") as f:
             mask = np.array(f[f"{self.PF8Config.bad_pixel_map_hdf5_path}"])
 
-        if config["skip_pol"]:
-            self.visual_data = data_visualize.visualize_data(data=data * mask)
+        if self.config["polarization"]["skip"]:
+            if (self.PF8Config.pf8_detector_info["nasics_x"] * self.PF8Config.pf8_detector_info["nasics_y"]
+                > 1
+            ):
+                self.visual_data = data_visualize.visualize_data(data=data * mask)
+                visual_mask = data_visualize.visualize_data(data=mask).astype(int)
+            else:
+                self.visual_data = visualize_single_panel(data, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
+                visual_mask = visualize_single_panel(mask, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
         else:
             pol_corrected_data, pol_array_map = correct_polarization(
-                self.pixel_maps["x"],
-                self.pixel_maps["y"],
-                float(np.mean(self.pixel_maps["z"]) * self.PF8Config.pixel_resolution),
-                frame,
+                self.PF8Config.pixel_maps["x"],
+                self.PF8Config.pixel_maps["y"],
+                float(np.mean(self.PF8Config.pixel_maps["z"]) * self.PF8Config.pixel_resolution),
+                data,
                 mask=mask,
-                polarization_axis=config["polarization_axis"],
-                p=config["polarization_value"],
-            )
-            self.visual_data = data_visualize.visualize_data(
-                data=pol_corrected_data * mask
+                polarization_axis=self.config["polarization"]["axis"],
+                p=self.config["polarization"]["value"],
             )
+            if (self.PF8Config.pf8_detector_info["nasics_x"] * self.PF8Config.pf8_detector_info["nasics_y"]
+                > 1
+            ):
+                self.visual_data = data_visualize.visualize_data(data=pol_corrected_data * mask)
+                visual_mask = data_visualize.visualize_data(data=mask).astype(int)
+            else:
+                self.visual_data = visualize_single_panel(pol_corrected_data, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
+                visual_mask = visualize_single_panel(mask, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
 
-        visual_mask = data_visualize.visualize_data(data=mask).astype(int)
 
         # JF for safety
         visual_mask[np.where(self.visual_data < 0)] = 0
 
         only_peaks_mask = mask_peaks(
-            visual_mask, indices, bragg=0, n=self.config["pixels_per_peak"]
+            visual_mask, peaks_indexes, bragg=0, n=self.config["pixels_for_mask_of_bragg_peaks"]
         )
         self.mask_for_fwhm_min = only_peaks_mask * visual_mask
 
@@ -329,12 +402,16 @@ class MinimizePeakFWHM(CenteringMethod):
             self.fwhm_summary = pool.map(self._calculate_fwhm, coordinates)
 
     def _run_centering(self, **kwargs) -> tuple:
-        center = open_fwhm_map_global_min(
+        if self.config["plots_flag"]:
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/fwhm_map/')
+            path.mkdir(parents=True, exist_ok=True)
+
+        center = get_fwhm_map_global_min(
             self.fwhm_summary,
-            f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["run_label"]}',
-            f'{self.plots_info["file_label"]}_{self.plots_info["frame_index"]}',
+            f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}',
+            f'{self.plots_info["file_name"]}',
             self.pixel_step,
-            self.config["plots_flag"],
+            self.config["plots_flag"]
         )
 
         if self.centering_converged(center):
@@ -342,14 +419,31 @@ class MinimizePeakFWHM(CenteringMethod):
             self._calculate_fwhm(center)
             self.plot_fwhm_flag = False
 
+        if self.config["plots_flag"]:
+            fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
+            ax1.imshow(self.visual_data * self.mask_for_fwhm_min, vmax=10, origin="lower", cmap="YlGn")
+            ax1.scatter(self.initial_detector_center[0], self.initial_detector_center[1], color='blue', marker='o', label=f"Initial detector center: ({np.round(self.initial_detector_center[0])}, {np.round(self.initial_detector_center[1])})")
+            ax1.scatter(self.initial_detector_center[0], self.initial_detector_center[1], color='blue', marker='o', label=f"Initial guess: ({np.round(self.initial_guess[0])}, {np.round(self.initial_guess[1])})")
+            ax1.scatter(center[0], center[1], color='r', marker='o', label=f"Refined detector center: ({center[0]}, {center[1]})")
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_fwhm_minimization/')
+            path.mkdir(parents=True, exist_ok=True)
+            ax1.legend()
+            plt.savefig(
+                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_fwhm_minimization/{self.plots_info["file_name"]}.png'
+            )
+            plt.close()
+
         return center
 
 
 class FriedelPairs(CenteringMethod):
-    def __init__(self, config: dict, PF8Config: PF8Info, plots_info: dict):
+    def __init__(self, config: dict, PF8Config: PF8Info, plots_info: dict = None):
         self.config = config
         self.PF8Config = PF8Config
         self.plots_info = plots_info
+        if config["plots_flag"] and not plots_info:
+            raise ValueError("From config you want to save plots, please indicate the information to save the plots.")
+
 
     def _remove_repeated_pairs(self, pairs_list: list) -> list:
         x_vector = []
@@ -457,21 +551,34 @@ class FriedelPairs(CenteringMethod):
         with h5py.File(f"{self.PF8Config.bad_pixel_map_filename}", "r") as f:
             mask = np.array(f[f"{self.PF8Config.bad_pixel_map_hdf5_path}"])
 
-        if config["skip_pol"]:
-            self.visual_data = data_visualize.visualize_data(data=data * mask)
+        if self.config["polarization"]["skip"]:
+            if (self.PF8Config.pf8_detector_info["nasics_x"] * self.PF8Config.pf8_detector_info["nasics_y"]
+                > 1
+            ):
+                self.visual_data = data_visualize.visualize_data(data=data * mask)
+                visual_mask = data_visualize.visualize_data(data=mask).astype(int)
+            else:
+                self.visual_data = visualize_single_panel(data, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
+                visual_mask = visualize_single_panel(mask, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
         else:
             pol_corrected_data, pol_array_map = correct_polarization(
-                self.pixel_maps["x"],
-                self.pixel_maps["y"],
-                float(np.mean(self.pixel_maps["z"]) * self.PF8Config.pixel_resolution),
-                data=data,
+                self.PF8Config.pixel_maps["x"],
+                self.PF8Config.pixel_maps["y"],
+                float(np.mean(self.PF8Config.pixel_maps["z"]) * self.PF8Config.pixel_resolution),
+                data,
                 mask=mask,
-                polarization_axis=config["polarization_axis"],
-                p=config["polarization_value"],
-            )
-            self.visual_data = data_visualize.visualize_data(
-                data=pol_corrected_data * mask
+                polarization_axis=self.config["polarization"]["axis"],
+                p=self.config["polarization"]["value"],
             )
+            if (self.PF8Config.pf8_detector_info["nasics_x"] * self.PF8Config.pf8_detector_info["nasics_y"]
+                > 1
+            ):
+                self.visual_data = data_visualize.visualize_data(data=pol_corrected_data * mask)
+                visual_mask = data_visualize.visualize_data(data=mask).astype(int)
+            else:
+                self.visual_data = visualize_single_panel(pol_corrected_data, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
+                visual_mask = visualize_single_panel(mask, self.PF8Config.transformation_matrix, self.PF8Config.ss_in_rows)
+
 
     def _run_centering(self, **kwargs) -> tuple:
         peak_list_x_in_frame = self.peak_list_x_in_frame.copy()
@@ -510,10 +617,14 @@ class FriedelPairs(CenteringMethod):
             )
 
         ## Minimize distance
-        center = open_distance_map_global_min(
+        if self.config["plots_flag"]:
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/distance_map/')
+            path.mkdir(parents=True, exist_ok=True)
+
+        center = get_distance_map_global_min(
             distance_summary,
-            f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["run_label"]}',
-            f'{self.plots_info["file_label"]}_{self.plots_info["frame_index"]}',
+            f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}',
+            f'{self.plots_info["file_name"]}',
             self.pixel_step,
             self.config["plots_flag"],
         )
@@ -523,30 +634,41 @@ class FriedelPairs(CenteringMethod):
             shift_y = 2 * (center[1] - self.initial_guess[1])
 
             fig, ax = plt.subplots(1, 1, figsize=(8, 8))
-            pos = ax.imshow(self.visual_data, vmin=0, vmax=100, cmap="YlGnBu")
+            pos = ax.imshow(self.visual_data, vmin=0, vmax=100, cmap="YlGn", origin="lower")
+            ax.scatter(
+                self.initial_detector_center[0],
+                self.initial_detector_center[1],
+                color="b",
+                marker="o",
+                s=25,
+                label=f"Initial detector center:({np.round(self.initial_detector_center[0],1)},{np.round(self.initial_detector_center[1], 1)})",
+            )
             ax.scatter(
                 self.initial_guess[0],
                 self.initial_guess[1],
                 color="lime",
                 marker="+",
                 s=150,
-                label=f"Initial center:({np.round(self.initial_guess[0],1)},{np.round(self.initial_guess[1], 1)})",
+                label=f"Initial guess:({np.round(self.initial_guess[0],1)},{np.round(self.initial_guess[1], 1)})",
             )
+            
             ax.scatter(
                 center[0],
                 center[1],
                 color="r",
                 marker="o",
                 s=25,
-                label=f"Refined center:({np.round(center[0],1)}, {np.round(center[1],1)})",
+                label=f"Refined detector center:({np.round(center[0],1)}, {np.round(center[1],1)})",
             )
             ax.set_xlim(200, 900)
             ax.set_ylim(900, 200)
             plt.title("Center refinement: autocorrelation of Friedel pairs")
             fig.colorbar(pos, shrink=0.6)
             ax.legend()
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/centered_friedel/')
+            path.mkdir(parents=True, exist_ok=True)
             plt.savefig(
-                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["run_label"]}/centered_friedel/{self.plots_info["file_label"]}_{self.plots_info["frame_index"]}.png'
+                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/centered_friedel/{self.plots_info["file_name"]}.png'
             )
             plt.close("all")
 
@@ -572,7 +694,7 @@ class FriedelPairs(CenteringMethod):
 
             ## Check pairs alignement
             fig, ax = plt.subplots(1, 1, figsize=(8, 8))
-            pos = ax.imshow(self.visual_data, vmin=0, vmax=100, cmap="YlGn")
+            pos = ax.imshow(self.visual_data, vmin=0, vmax=100, cmap="YlGn", origin="lower")
             ax.scatter(
                 original_peaks_x,
                 original_peaks_y,
@@ -610,8 +732,10 @@ class FriedelPairs(CenteringMethod):
             plt.title("Bragg peaks alignement")
             fig.colorbar(pos, shrink=0.6)
             ax.legend()
+            path = pathlib.Path(f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/peaks/')
+            path.mkdir(parents=True, exist_ok=True)
             plt.savefig(
-                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["run_label"]}/peaks/{self.plots_info["file_label"]}_{self.plots_info["frame_index"]}.png'
+                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/peaks/{self.plots_info["file_name"]}.png'
             )
             plt.close()
         return center
